@@ -59,8 +59,8 @@ RcppExport SEXP RtoGlm(SEXP params, SEXP Ysexp, SEXP Xsexp)
     }
        
     // do stuff	
-//  clock_t clk_start, clk_end;
-//  clk_start = clock();
+    clock_t clk_start, clk_end;
+    clk_start = clock();
 
     PoissonGlm pfit(&mm);
     LogiGlm lfit(&mm);
@@ -70,9 +70,12 @@ RcppExport SEXP RtoGlm(SEXP params, SEXP Ysexp, SEXP Xsexp)
     glmPtr[mtype]->regression(Y, X, NULL);
 //    glmPtr[mtype]->display();
 	
-//    clk_end = clock();
-//    float dif = (float)(clk_end - clk_start)/(float)(CLOCKS_PER_SEC);
-//    Rprintf("Time elapsed: %.4f seconds\n", dif);
+    clk_end = clock();
+    long int dif = floor((double)(clk_end - clk_start)/(double)(CLOCKS_PER_SEC));
+    unsigned int hours = floor((double)(dif/(double)3600));
+    unsigned int min = floor((double)(dif%3600)/(double)60);
+    unsigned int sec = dif%60;
+//    Rprintf("Time elapsed: %d hr %d min %d sec (%d seconds)\n", hours, min, sec, dif);
 
     // Wrap the glm object with Rcpp 
     NumericVector phi(glmPtr[mtype]->phi, glmPtr[mtype]->phi+nVars);
